==> regina-normal_5.1.orig.tar.gz: regina-5.1/python/angle/anglestructure.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include <boost/python.hpp>
#include "angle/anglestructure.h"
#include "triangulation/dim3.h"
#include "../helpers.h"
#include "../safeheldtype.h"

using namespace boost::python;
using namespace regina::python;
using regina::AngleStructure;

void addAngleStructure() {
    class_<AngleStructure, std::auto_ptr<AngleStructure>, boost::noncopyable>
            ("AngleStructure", no_init)
        .def("clone", &AngleStructure::clone,
            return_value_policy<manage_new_object>())
        .def("angle", &AngleStructure::angle)
        .def("triangulation", &AngleStructure::triangulation,
            return_value_policy<to_held_type<> >())
        .def("isStrict", &AngleStructure::isStrict)
        .def("isTaut", &AngleStructure::isTaut)
        .def("isVeering", &AngleStructure::isVeering)
        .def(regina::python::add_output())
        .def(regina::python::add_eq_operators())
    ;

    scope().attr("NAngleStructure") = scope().attr("AngleStructure");
}

==> regina-normal_6.0.1.orig.tar.gz: regina-6.0.1/python/angle/anglestructure.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2021, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "angle/anglestructure.h"
#include "triangulation/dim3.h"
#include "../helpers.h"

using namespace regina::python;
using regina::AngleStructure;

void addAngleStructure(pybind11::module_& m) {
    auto c = pybind11::class_<AngleStructure>(m, "AngleStructure")
        .def("clone", &AngleStructure::clone)
        .def("angle", &AngleStructure::angle)
        .def("triangulation", &AngleStructure::triangulation)
        .def("isStrict", &AngleStructure::isStrict)
        .def("isTaut", &AngleStructure::isTaut)
        .def("isVeering", &AngleStructure::isVeering)
    ;
    regina::python::add_output(c);
    regina::python::add_eq_operators(c);

    m.attr("NAngleStructure") = m.attr("AngleStructure");
}
